@@ -46,8 +46,8 @@ import net
 from tool import load
 
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 # Development Status :: 1 - Planning, 2 - Pre-Alpha, 3 - Alpha,
 #                       4 - Beta, 5 - Production/Stable
-__status__ = '5 - Production/Stable'
+__status__ = '4 - Beta'
