@@ -1,9 +1,9 @@
 ﻿import unittest
-from test.trans import TestTrans
-from test.error import TestError
+from trans import TestTrans
+from error import TestError
 
 suite = unittest.TestSuite()
 suite.addTest(unittest.makeSuite(TestTrans))
 suite.addTest(unittest.makeSuite(TestError))
 
-unittest.TextTestRunner(verbosity=2).run(suite)
\ No newline at end of file
+unittest.TextTestRunner(verbosity=2).run(suite)
